KeyRotation

Struct KeyRotation 

pub struct KeyRotation {
    pub type_: String,
    pub version: String,
    pub did: String,
    pub rotation_type: RotationType,
    pub new_key: NewKey,
    pub previous_key: String,
    pub effective_at: i64,
    pub overlap_until: i64,
    pub reason: RotationReason,
    pub signature: Option<String>,
}
A key rotation event.

Fields

type_: String

Type identifier.

version: String

Protocol version.

did: String

The DID this rotation is for.

rotation_type: RotationType

Type of rotation.

new_key: NewKey

The new key.

previous_key: String

Reference to the previous key.

effective_at: i64

When this rotation takes effect (unix ms).

overlap_until: i64

When the overlap period ends (unix ms).

reason: RotationReason

Reason for rotation.

signature: Option<String>

Signature from the previous key.

Implementations

Source

impl KeyRotation

pub const DEFAULT_OVERLAP: Duration

Default overlap period (24 hours).

pub fn new( did: Did, rotation_type: RotationType, new_key: NewKey, previous_key: String, reason: RotationReason, ) -> Self

Create a new unsigned key rotation.

pub fn effective_at(self, time: DateTime<Utc>) -> Self

Set custom effective time.

pub fn overlap_duration(self, duration: Duration) -> Self

Set custom overlap period.

pub fn sign(self, old_key: &RootKey) -> Result<Self>

Sign this rotation with the previous (old) key.

pub fn verify(&self) -> Result<()>

Verify this rotation’s signature against the DID’s public key.

pub fn is_old_key_valid_at(&self, time: DateTime<Utc>) -> bool

Check if a key is valid at a given time (considering overlap).

pub fn is_new_key_active_at(&self, time: DateTime<Utc>) -> bool

Check if the new key is active at a given time.