pub struct KeyRotation {
pub type_: String,
pub version: String,
pub did: String,
pub rotation_type: RotationType,
pub new_key: NewKey,
pub previous_key: String,
pub effective_at: i64,
pub overlap_until: i64,
pub reason: RotationReason,
pub signature: Option<String>,
}Expand description
A key rotation event.
Fields
type_: StringType identifier.
version: StringProtocol version.
did: StringThe DID this rotation is for.
rotation_type: RotationTypeType of rotation.
new_key: NewKeyThe new key.
previous_key: StringReference to the previous key.
effective_at: i64When this rotation takes effect (unix ms).
overlap_until: i64When the overlap period ends (unix ms).
reason: RotationReasonReason for rotation.
signature: Option<String>Signature from the previous key.
Implementations
Sourceimpl KeyRotation
impl KeyRotation
Sourcepub const DEFAULT_OVERLAP: Duration
pub const DEFAULT_OVERLAP: Duration
Default overlap period (24 hours).
Sourcepub fn new(
did: Did,
rotation_type: RotationType,
new_key: NewKey,
previous_key: String,
reason: RotationReason,
) -> Self
pub fn new( did: Did, rotation_type: RotationType, new_key: NewKey, previous_key: String, reason: RotationReason, ) -> Self
Create a new unsigned key rotation.
Sourcepub fn effective_at(self, time: DateTime<Utc>) -> Self
pub fn effective_at(self, time: DateTime<Utc>) -> Self
Set custom effective time.
Sourcepub fn overlap_duration(self, duration: Duration) -> Self
pub fn overlap_duration(self, duration: Duration) -> Self
Set custom overlap period.
Sourcepub fn sign(self, old_key: &RootKey) -> Result<Self>
pub fn sign(self, old_key: &RootKey) -> Result<Self>
Sign this rotation with the previous (old) key.
Sourcepub fn verify(&self) -> Result<()>
pub fn verify(&self) -> Result<()>
Verify this rotation’s signature against the DID’s public key.
Sourcepub fn is_old_key_valid_at(&self, time: DateTime<Utc>) -> bool
pub fn is_old_key_valid_at(&self, time: DateTime<Utc>) -> bool
Check if a key is valid at a given time (considering overlap).
Sourcepub fn is_new_key_active_at(&self, time: DateTime<Utc>) -> bool
pub fn is_new_key_active_at(&self, time: DateTime<Utc>) -> bool
Check if the new key is active at a given time.